@@ -5,16 +5,12 @@ import matplotlib
 import cv2 as cv
 from src import stats
 from src import ImageProcessing
-import tkinter
-matplotlib.use('tkAgg')
-import matplotlib.pyplot as plt
+matplotlib.use('TkAgg')
 import statistics as stat
 from skimage import feature
 import time
-import multiprocessing
 import random
 from scipy import signal
-import multiprocessing
 from joblib import Parallel, delayed
 from tqdm import tqdm
 
