@@ -41,10 +41,10 @@ def getScore(cool, coordinates,norm,header,numcores,out,mask='0'):
     pval = getStripe.getStripe.pvalue(obj, bgleft, bgright, table)
     table.insert(table.shape[1],'pvalue_added',pval,True)
     MEAN, SUM = getStripe.getStripe.getMean(obj,table)
-    s,MEAN,TOTAL = obj.scoringstripes(table,mask)
+    s,MEANOE,TOTALOE = obj.scoringstripes(table,mask)
     table.insert(table.shape[1],'Stripiness_added',s,True)
     table.insert(table.shape[1], "O_Mean_added", MEAN, True)
     table.insert(table.shape[1], "O_Sum_added", SUM, True)
-    table.insert(table.shape[1], 'O/E_Mean_added',MEAN,True)
-    table.insert(table.shape[1], 'O/E_Total_added',TOTAL,True)
+    table.insert(table.shape[1], 'O/E_Mean_added',MEANOE,True)
+    table.insert(table.shape[1], 'O/E_Total_added',TOTALOE,True)
     table.to_csv(out,sep="\t",header=True,index=False)
